==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/openShop/ClientInfo.java <==
package eleme.openapi.sdk.api.entity.openShop;

public class ClientInfo{

    /**
     * 设备id
     */
    private String deviceId;
    public String getDeviceId() {
        return deviceId;
    }
    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }
    
    /**
     * 客户端ip
     */
    private String clientIp;
    public String getClientIp() {
        return clientIp;
    }
    public void setClientIp(String clientIp) {
        this.clientIp = clientIp;
    }
    
    /**
     * 客户端平台
     */
    private String clientPlatform;
    public String getClientPlatform() {
        return clientPlatform;
    }
    public void setClientPlatform(String clientPlatform) {
        this.clientPlatform = clientPlatform;
    }
    
    /**
     * 客户端经度
     */
    private Double longitude;
    public Double getLongitude() {
        return longitude;
    }
    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }
    
    /**
     * 客户端纬度
     */
    private Double latitude;
    public Double getLatitude() {
        return latitude;
    }
    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }
    
    /**
     * 操作人名称
     */
    private String userName;
    public String getUserName() {
        return userName;
    }
    public void setUserName(String userName) {
        this.userName = userName;
    }
    
    /**
     * 操作人手机号
     */
    private String userMobile;
    public String getUserMobile() {
        return userMobile;
    }
    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }
    
}

==> eleme-openapi-sdk-1.30.85-sources.jar: eleme/openapi/sdk/api/entity/openShop/ClientInfo.java <==
package eleme.openapi.sdk.api.entity.openShop;

import eleme.openapi.sdk.api.enumeration.openShop.*;
import eleme.openapi.sdk.api.entity.openShop.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class ClientInfo{

    /**
     * 设备id
     */
    private String deviceId;
    public String getDeviceId() {
        return deviceId;
    }
    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }
    
    /**
     * 客户端ip
     */
    private String clientIp;
    public String getClientIp() {
        return clientIp;
    }
    public void setClientIp(String clientIp) {
        this.clientIp = clientIp;
    }
    
    /**
     * 客户端平台
     */
    private String clientPlatform;
    public String getClientPlatform() {
        return clientPlatform;
    }
    public void setClientPlatform(String clientPlatform) {
        this.clientPlatform = clientPlatform;
    }
    
    /**
     * 客户端经度
     */
    private Double longitude;
    public Double getLongitude() {
        return longitude;
    }
    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }
    
    /**
     * 客户端纬度
     */
    private Double latitude;
    public Double getLatitude() {
        return latitude;
    }
    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }
    
    /**
     * 操作人名称
     */
    private String userName;
    public String getUserName() {
        return userName;
    }
    public void setUserName(String userName) {
        this.userName = userName;
    }
    
    /**
     * 操作人手机号
     */
    private String userMobile;
    public String getUserMobile() {
        return userMobile;
    }
    public void setUserMobile(String userMobile) {
        this.userMobile = userMobile;
    }
    
}
